#!/bin/bash
#center.sh

#ファインダーと望遠鏡の光軸を一致させるスクリプト
#pointing_main.shを実行後、このスクリプトを実行することで望遠鏡中心がファインダーでどこに相当するか
#自動的に学習し反映させる事が出来る。基本的に人がいるときに観測前に1回のみ実行する。

OKITA="okita@192.168.161.90"

#ディレクトリの移動 for sextractor
cd /program/LX200/

#露出時間の読み込み
exposure=`awk '{print $1}' /program/LX200/exposure_finder/finder.exposure`


#(1)ファインダーによる撮像を5回繰り返す
rm -rf /program/LX200/pointing_finder/*.fits
i=1
while [ $i -le 5 ]
do
    i=`printf "%03d" $i`
    rm -rf /program/LX200/command/finder_ccd.sh
    printf "#!/bin/bash\n
night_exposure -t $exposure -s on -b 1 -o /program/LX200/pointing_finder/pointing$i.fits" >> /program/LX200/command/finder_ccd.sh
    sh /program/LX200/command/finder_ccd.sh

    i=`expr $i + 1`
done


#(2)sextractorで星の情報を抽出し、awkで最輝星の(x,y)を抽出
rm -rf /program/LX200/sextractor/image_stat.dat
i=1
while [ $i -le 5 ]
do
    i=`printf "%03d" $i`
    cd /program/LX200/sextractor/
    sex /program/LX200/pointing_finder/pointing$i.fits > /dev/null
    cd /program/LX200/
    awk -f /program/LX200/sextractor/image_stat.awk /program/LX200/sextractor/test.cat >> /program/LX200/sextractor/image_stat.dat
    i=`expr $i + 1`
done
rm -rf /program/LX200/sextractor/test.cat


#(3)awkで最輝星の(x,y)のメジアンを計算する
rm -rf /program/LX200/pointing_finder/finder.current
awk -f /program/LX200/pointing_finder/current_pointing.awk /program/LX200/sextractor/image_stat.dat > /program/LX200/pointing_finder/finder.current


#(4)'gnuplotによる表示(省略可)
cat /program/LX200/pointing_finder/finder.current >> /program/LX200/pointing_finder/finder.tmp
gnuplot /program/LX200/pointing_finder/current_pointing.plt


#(5)もしfinder.currentが0,0で無ければfinder.originalをfinder.currentで上書きして終了

xcur=`awk '{print $1}' /program/LX200/pointing_finder/finder.current`
ycur=`awk '{print $2}' /program/LX200/pointing_finder/finder.current`
if test $xcur -ne 0
then
    rm -rf /program/LX200/pointing_finder/finder.original
    cp -a /program/LX200/pointing_finder/finder.current /program/LX200/pointing_finder/finder.original
    scp -rp /program/LX200/pointing_finder/finder.original $OKITA:/program/LX200/pointing_finder/.

    #gnulpot用のデータを削除
    rm -rf /program/LX200/pointing_finder/finder.tmp
    
    echo "CENTER SUCCESSFUL"
    exit 0

else

    #gnulpot用のデータを削除
    rm -rf /program/LX200/pointing_finder/finder.tmp

    echo "CENTER FAULT"
    exit 1
fi


