#!/bin/bash
#dimm.sh

#ディレクトリの移動
cd /program/LX200/

#露出時間の設定（デフォルトは0.001秒）
exposure=0.001

#(1)LX200から天体の高度を取得し、天頂角を計算(単位はdegree)
#ちなみにASCII 223（°）がコマンドに含まれる場合は、16進数表記 \xDF を用いて削除する
rm -rf /program/LX200/dimm/height.dat
rm -rf /program/LX200/command/lx200.sh
printf "#!/bin/bash\n
/program/LX200/meade :GA# -r 4 | sed -e 's/[^0-9,-]/ /g' | sed -e 's/\xDF/ /g'  >> /program/LX200/dimm/height.dat\n" >> /program/LX200/command/lx200.sh
sh /program/LX200/command/lx200.sh
Z_ANGLE=`awk '{print (90-$1-$2/60.0-$3/3600.0)}' /program/LX200/dimm/height.dat`



#(2)主望遠鏡CCDで撮像(DIMM観測データの取得)。$exposure(デフォルトは0.001秒)で40枚撮像。

#フォルダ名(観測開始時刻)の設定（世界時）
UNIXTIME=`date +%s`
mkdir /program/LX200/dimm/rawdata/$UNIXTIME


#40枚撮影のループ
i=1
while [ $i -le 40 ]
do
    i=`printf "%03d" $i`
    rm -rf /program/LX200/command/main_ccd.sh
    printf "#!/bin/bash\n
night_exposure -t $exposure -s on -b 1 -o /program/LX200/dimm/rawdata/$UNIXTIME/dimm$i.fits" >> /program/LX200/command/main_ccd.sh
    sh /program/LX200/command/main_ccd.sh
    i=`expr $i + 1`
done



#(3)sextractorで星の情報を抽出し、awkで最輝星と2番目に明るい星を算出
rm -rf /program/LX200/sextractor_dimm/image_stat.dat
i=1
while [ $i -le 40 ]
do
    i=`printf "%03d" $i`
    cd /program/LX200/sextractor_dimm/
    sex /program/LX200/dimm/rawdata/$UNIXTIME/dimm$i.fits > /dev/null
    cd /program/LX200/
    awk -f /program/LX200/sextractor_dimm/image_stat.awk /program/LX200/sextractor_dimm/test.cat >> /program/LX200/sextractor_dimm/image_stat.dat
    i=`expr $i + 1`
done
rm -rf /program/LX200/sextractor_dimm/test.cat



#(4)2星のl方向、t方向の平均・分散を計算し、シーイングを算出
/program/LX200/dimm/dimm /program/LX200/sextractor_dimm/image_stat.dat $Z_ANGLE $UNIXTIME >> /program/LX200/dimm/result.dimm

echo "DIMM OBSERVATION SUCCESSFUL"
exit 0
