/* dimm.c */
/* gcc -lm -o /program/LX200/dimm/dimm /program/LX200/dimm/dimm.c */
/* image_stat.datに保存したDIMMで得られた2星の位置の差を計算し、l方向・t方向の平均と分散を求める。*/
/* 天頂角(degree)をコマンドラインから得て、l方向・t方向のシーイングを計算する。*/
/* 引数1 データファイル名 */
/* 引数2 天頂角(degree) */
/* 引数3 時刻(Unix Time) */

#include <stdio.h>
#include <math.h>
#include <stdlib.h>
#include "/program/LX200/dimm/parameters.h"
#define PI 3.141592


int main(int argc, char *argv[]){

    int i=0, f, j, k;
    double z, a, b, c, d, e, x1, y1, x2, y2, l[40], t[40], lave=0.0, tave=0.0, lstd=0.0, tstd=0.0, lseeing=0.0, tseeing=0.0;
    FILE *fi;

    /*コマンドラインから得た天頂角をradian単位に変換*/
    z=atof(argv[2])/180.0*PI;


    /*初回読み込み*/
    /*ファイル読み込みをして、l方向・t方向それぞれの2星の距離を計算*/
    fi = fopen(argv[1],"r");
    while( fscanf(fi,"%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%d\n",&a,&b,&c,&d,&e,&x1,&y1,&x2,&y2,&f) != EOF ){
        if (f==2){
            l[i]=fabs(x1-x2);    /*l方向(x方向)の2星の距離*/
            t[i]=fabs(y1-y2);    /*t方向(y方向)の2星の距離*/
            i++;
        }
    }
    fclose(fi);

    /*lとtの平均を計算*/
    for(j=0; j<i; j++) {
        lave=lave+l[j];
        tave=tave+t[j];
    }
    lave=lave/i;
    tave=tave/i;

    /*lとtの分散を計算*/
    for(j=0; j<i; j++) {
        lstd=lstd+(l[j]-lave)*(l[j]-lave);
        tstd=tstd+(t[j]-tave)*(t[j]-tave);
    }
    lstd=sqrt(lstd/(i-1));
    tstd=sqrt(tstd/(i-1));



    /*sigma clipping*/
    /*とりあえず5σで20回*/
    for(k=0;k<20;k++){

        i=0;
        /*ファイル読み込みをして、l方向・t方向それぞれの2星の距離を計算*/
        fi = fopen(argv[1],"r");
        while( fscanf(fi,"%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%lf\t%d\n",&a,&b,&c,&d,&e,&x1,&y1,&x2,&y2,&f) != EOF ){
            if (f==2){
                if(fabs(x1-x2)>(lave-5*lstd) && fabs(x1-x2)<(lave+5*lstd) && fabs(y1-y2)>(tave-5*tstd) && fabs(y1-y2)<(tave+5*tstd)){
                    if(fabs(x1-x2)>(lave-40) && fabs(x1-x2)<(lave+40) && fabs(y1-y2)>(tave-40) && fabs(y1-y2)<(tave+40)){
                        l[i]=fabs(x1-x2);    /*l方向(x方向)の2星の距離*/
                        t[i]=fabs(y1-y2);    /*t方向(y方向)の2星の距離*/
                        i++;
                    }
                }
            }
        }
        fclose(fi);

        /*lとtの平均を計算*/
        lave=0.0;
        tave=0.0;
        for(j=0; j<i; j++) {
            lave=lave+l[j];
            tave=tave+t[j];
        }
        lave=lave/i;
        tave=tave/i;

        /*lとtの分散を計算*/
        lstd=0.0;
        tstd=0.0;
        for(j=0; j<i; j++) {
            lstd=lstd+(l[j]-lave)*(l[j]-lave);
            tstd=tstd+(t[j]-tave)*(t[j]-tave);
        }
        lstd=sqrt(lstd/(i-1));
        tstd=sqrt(tstd/(i-1));
    }



    /*radian単位に変換*/
    lstd=lstd*PIXSIZE/3600.0*(PI/180.0);
    tstd=tstd*PIXSIZE/3600.0*(PI/180.0);

    /*l方向とt方向のシーイングを計算する(結果はradian) */
    lseeing=0.646559*pow(LAMBDA, -0.2)*pow((lstd*lstd*cos(z)/(0.179*pow(DIAMETER,-1.0/3.0)-0.0968*pow(DISTANCE,-1.0/3.0))),0.6);
    tseeing=0.646559*pow(LAMBDA, -0.2)*pow((tstd*tstd*cos(z)/(0.179*pow(DIAMETER,-1.0/3.0)-0.145*pow(DISTANCE,-1.0/3.0))),0.6);


    /*結果の表示、時刻、天頂角、計算に用いた画像数、平均距離(pixel)、分散(pixel)、シーイング(arcsec)*/
    printf("%s\t%.3f\t%d\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n",argv[3],z,i,lave,tave,lstd*180/PI*3600/PIXSIZE,tstd*180/PI*3600/PIXSIZE,lseeing*180/PI*3600,tseeing*180/PI*3600);

return 0;
}
